﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System.Collections;
using System.Collections.Generic;
using System.Collections.Specialized;
using Microsoft.Practices.Prism.Regions;

namespace EnnfDesigner.Test.Mocks
{
    class RegionCollectionMock : IRegionCollection 
    {
        private Dictionary<string,IRegion> _regions = new Dictionary<string, IRegion>(); 
        #region Implementation of IEnumerable

        public IEnumerator<IRegion> GetEnumerator()
        {
            return _regions.Values.GetEnumerator();
        }

        IEnumerator IEnumerable.GetEnumerator()
        {
            return GetEnumerator();
        }

        #endregion

        #region Implementation of INotifyCollectionChanged

        public event NotifyCollectionChangedEventHandler CollectionChanged;

        #endregion

        #region Implementation of IRegionCollection

        public void Add(IRegion region)
        {
            _regions.Add(region.Name,region);
            if (CollectionChanged == null) return;
            NotifyCollectionChangedEventArgs args = new NotifyCollectionChangedEventArgs(NotifyCollectionChangedAction.Add);
            CollectionChanged(this, args);
        }

        public bool Remove(string regionName)
        {
            bool toreturn = _regions.Remove(regionName);

            if (CollectionChanged == null) return toreturn;
            NotifyCollectionChangedEventArgs args = new NotifyCollectionChangedEventArgs(NotifyCollectionChangedAction.Remove);
            CollectionChanged(this, args);

            return toreturn;
        }

        public bool ContainsRegionWithName(string regionName)
        {
            bool toreturn = _regions.ContainsKey(regionName);

            if (CollectionChanged == null) return toreturn;
            NotifyCollectionChangedEventArgs args = new NotifyCollectionChangedEventArgs(NotifyCollectionChangedAction.Remove);
            CollectionChanged(this, args);

            return toreturn;
        }

        public IRegion this[string regionName]
        {
            get { return _regions[regionName]; }
        }

        #endregion
    }
}
