﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using Microsoft.Practices.Prism.Regions;

namespace EnnfDesigner.Test.Mocks
{
    class RegionMock : IRegion
    {
        readonly Dictionary<string,object> _addedViews = new Dictionary<string, object>();
        readonly IRegionManager _regionManager = new RegionManagerMock();

        #region Implementation of INavigateAsync

        public void RequestNavigate(Uri target, Action<NavigationResult> navigationCallback)
        {
            throw new NotImplementedException();
        }

        #endregion

        #region Implementation of INotifyPropertyChanged

        public event PropertyChangedEventHandler PropertyChanged;

        #endregion

        private object SelectedItem { get; set; }

        #region Implementation of IRegion

        public IRegionManager Add(object view)
        {
            _addedViews.Add(Name,view);
            return _regionManager;
        }

        public IRegionManager Add(object view, string viewName)
        {
            _addedViews.Add(viewName,view);
            return _regionManager;
        }

        public IRegionManager Add(object view, string viewName, bool createRegionManagerScope)
        {
            _addedViews.Add(viewName,view);
            return _regionManager;
        }

        public void Remove(object view)
        {
            var selection = from obj in _addedViews
                            where obj.Value == view
                            select obj.Key;

            string key = selection.SingleOrDefault();
            if (key != null && _addedViews.ContainsKey(key))
                _addedViews.Remove(key);
        }

        public void Activate(object view)
        {
            SelectedItem = view;
        }

        public void Deactivate(object view)
        {
            SelectedItem = null;
        }

        public object GetView(string viewName)
        {
            return _addedViews[viewName];
        }

        public IViewsCollection Views { get; set; }

        public IViewsCollection ActiveViews { get; set; }

        public object Context { get; set; }

        public string Name { get; set; }

        public Comparison<object> SortComparison { get; set; }

        public IRegionManager RegionManager { get; set; }

        public IRegionBehaviorCollection Behaviors { get; private set; }

        public IRegionNavigationService NavigationService { get; set; }

        #endregion
    }
}
