﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using Ennf;
using EnnfDesigner.Test.Mocks;
using EnnfDesigner.ViewModels;
using Microsoft.Practices.Unity;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace EnnfDesigner.Test
{
    [TestClass]
    public class ShellViewModelUnitTests
    {
        private static IUnityContainer _container;
        private static Bootstrapper _strapper;

        [ClassInitialize]
        public static void MyClassInitialize(TestContext testContext)
        {
            _strapper = new Bootstrapper();
            _strapper.Run();
            _container = _strapper.Container;
            //_container.LoadConfiguration("Navigation");
        }

        [TestCategory("UnitTests"), TestCategory("ShellView Model Test"), TestMethod]
        public void TestLoadNetwork()
        {
            RegionManagerMock regionManager = new RegionManagerMock();
            EventAggregatorMock eventAggregator = new EventAggregatorMock();

            ShellViewModel shellViewModel = new ShellViewModel(regionManager,eventAggregator,_container);
            shellViewModel.LoadNetwork.Execute(null);

            Assert.IsTrue(shellViewModel.NetworkLoaded);
        }

        [TestCategory("UnitTests"), TestCategory("ShellView Model Test"), TestMethod]
        public void TestCloseNetwork()
        {
            // Setup Network
            RegionManagerMock regionManager = new RegionManagerMock();
            EventAggregatorMock eventAggregator = new EventAggregatorMock();

            ShellViewModel shellViewModel = new ShellViewModel(regionManager, eventAggregator, _container);
            shellViewModel.LoadNetwork.Execute(null);

            // Now close it
            shellViewModel.CloseNetwork.Execute();
            Assert.IsFalse(shellViewModel.NetworkLoaded);
        }

        [TestCategory("UnitTests"), TestCategory("ShellView Model Test"), TestMethod]
        public void TestCloseApplication()
        {
            // Setup Network
            RegionManagerMock regionManager = new RegionManagerMock();
            EventAggregatorMock eventAggregator = new EventAggregatorMock();

            ShellViewModel shellViewModel = new ShellViewModel(regionManager, eventAggregator, _container);
            shellViewModel.CloseApplication.Execute();
        }

        [TestCategory("UnitTests"), TestCategory("ShellView Model Test"), TestMethod]
        public void TestOpenConsole()
        {
            // Setup Network
            RegionManagerMock regionManager = new RegionManagerMock();
            EventAggregatorMock eventAggregator = new EventAggregatorMock();

            ShellViewModel shellViewModel = new ShellViewModel(regionManager, eventAggregator, _container);
            shellViewModel.LoadNetwork.Execute(null);
            // Find network
            Assert.IsTrue(shellViewModel.Networks.MoveCurrentToFirst());
            shellViewModel.OpenConsole.Execute(shellViewModel.Networks.CurrentItem as INetwork);
        }
    }
}
