﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System;
using System.Diagnostics.Contracts;
using System.IO;
using System.Linq;
using System.Xml.Linq;
using Ennf.Properties;
using Ennf.Utilities;
using Microsoft.Practices.Unity;

namespace Ennf
{
    public class Container : IPersistenceModel
    {
        #region Properties
        public IUnityContainer UnityContainer { get; set; }

        public INetworkModel NetworkModel { get; set; }
        #endregion

        #region Constructors
        public Container(IUnityContainer unityContainer)
        {
            UnityContainer = unityContainer;
            NetworkModel = new NullNetworkModel();
        }
        #endregion

        #region Implementation of IPersistenceModel

        public void LoadFile(string fileName)
        {
            /*Contract.Requires<ArgumentNullException>(!string.IsNullOrEmpty(fileName));
            Contract.Requires<ArgumentException>(File.Exists(fileName));

            Contract.Ensures(NetworkModel.PersistenceModel != null);
            Contract.Ensures(NetworkModel != null);*/

            string modelType;
            // pick out the required model
            using (FileStream fs = new FileStream(fileName, FileMode.Open, FileAccess.Read, FileShare.None))
            {
                XDocument document = XDocument.Load(fs);
                var query = from element in document.Elements()
                            select element.Attribute("ModelType");
                modelType = query.Single().Value;
                //fs.Close();
            }

            IPersistenceModel persistenceModel = UnityContainer.Resolve<IPersistenceModel>(modelType);
            //Contract.Assert(persistenceModel != null);
            persistenceModel.LoadFile(fileName);
            NetworkModel = UnityContainer.Resolve<INetworkModel>(modelType,new ParameterOverride("context",persistenceModel));
            //Contract.Assert(NetworkModel != null);
            NetworkModel.PersistenceModel = persistenceModel;
        }

        public void ConnectDatabase(string connectionString)
        {
            ConnectDatabase(Resources.DefaultModelTypeDatabase,connectionString);
        }

        public void ConnectDatabase(string modelType, string connectionString)
        {
            Contract.Ensures(NetworkModel.PersistenceModel != null);
            Contract.Ensures(NetworkModel != null);

            IPersistenceModel persistenceModel = UnityContainer.Resolve<IPersistenceModel>(modelType, new ParameterOverride("connectionString",connectionString));
            Contract.Assert(persistenceModel != null);
            NetworkModel = UnityContainer.Resolve<INetworkModel>(modelType,new ParameterOverride("context",persistenceModel));
            Contract.Assert(NetworkModel != null);
            NetworkModel.PersistenceModel = persistenceModel;
        }

        public void Close()
        {
            NetworkModel.PersistenceModel.Close();
        }

        public int SaveChanges()
        {
            return 0;
        }
        
        #endregion
    }
}
