﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System.Collections.Generic;
using System.Data.Entity.Infrastructure;
using System.Data.Entity.Validation;
using System.Linq;

namespace Ennf.DbEntityAdapter
{
    internal class DbCollectionEntryAdapter<TEntity, TElement> : IDbCollectionEntry<TEntity, TElement>
        where TEntity : class
    {
        private readonly DbCollectionEntry<TEntity, TElement> _CollectionEntry;

        public DbCollectionEntryAdapter(DbCollectionEntry<TEntity, TElement> collectionEntry)
        {
            _CollectionEntry = collectionEntry;
        }

        #region IDbCollectionEntry<TEntity,TElement> Members

        public ICollection<TElement> CurrentValue
        {
            get { return _CollectionEntry.CurrentValue; }
            set { _CollectionEntry.CurrentValue = value; }
        }

        public IDbEntityEntry<TEntity> EntityEntry
        {
            get { return new DbEntityEntryAdapter<TEntity>(_CollectionEntry.EntityEntry); }
        }

        public bool IsLoaded
        {
            get { return _CollectionEntry.IsLoaded; }
        }

        public string Name
        {
            get { return _CollectionEntry.Name; }
        }

        public void Load()
        {
            _CollectionEntry.Load();
        }

        public IQueryable<TElement> Query()
        {
            return _CollectionEntry.Query();
        }

        public ICollection<DbValidationError> GetValidationErrors()
        {
            return _CollectionEntry.GetValidationErrors();
        }

        #endregion
    }
}