﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity.Infrastructure;
using System.Data.Entity.Validation;
using System.Linq.Expressions;

namespace Ennf.DbEntityAdapter
{
    internal class DbEntityEntryAdapter<TEntity> : IDbEntityEntry<TEntity> where TEntity : class
    {
        private readonly DbEntityEntry<TEntity> _entityEntry;

        public DbEntityEntryAdapter(DbEntityEntry<TEntity> entityEntry)
        {
            _entityEntry = entityEntry;
        }

        #region IDbEntityEntry<TEntity> Members

        public DbPropertyValues CurrentValues
        {
            get { return _entityEntry.CurrentValues; }
        }

        public TEntity Entity
        {
            get { return _entityEntry.Entity; }
        }

        public DbPropertyValues OriginalValues
        {
            get { return _entityEntry.OriginalValues; }
        }

        public EntityState State
        {
            get { return _entityEntry.State; }
            set { _entityEntry.State = value; }
        }

        public IDbCollectionEntry<TEntity, TElement> Collection<TElement>(
            Expression<Func<TEntity, ICollection<TElement>>> navigationProperty) where TElement : class
        {
            return new DbCollectionEntryAdapter<TEntity, TElement>(_entityEntry.Collection(navigationProperty));
        }

        public IDbCollectionEntry<TEntity, TElement> Collection<TElement>(string navigationProperty)
            where TElement : class
        {
            return new DbCollectionEntryAdapter<TEntity, TElement>(_entityEntry.Collection<TElement>(navigationProperty));
        }

        public DbCollectionEntry Collection(string navigationProperty)
        {
            return _entityEntry.Collection(navigationProperty);
        }

        public DbComplexPropertyEntry<TEntity, TComplexProperty> ComplexProperty<TComplexProperty>(
            Expression<Func<TEntity, TComplexProperty>> property)
        {
            return _entityEntry.ComplexProperty(property);
        }

        public DbComplexPropertyEntry<TEntity, TComplexProperty> ComplexProperty<TComplexProperty>(string propertyName)
        {
            return _entityEntry.ComplexProperty<TComplexProperty>(propertyName);
        }

        public DbComplexPropertyEntry ComplexProperty(string propertyName)
        {
            return _entityEntry.ComplexProperty(propertyName);
        }

        public bool Equals(DbEntityEntry<TEntity> other)
        {
            return _entityEntry.Equals(other);
        }

        public DbPropertyValues GetDatabaseValues()
        {
            return _entityEntry.GetDatabaseValues();
        }

        public DbEntityValidationResult GetValidationResult()
        {
            return _entityEntry.GetValidationResult();
        }

        public DbMemberEntry Member(string propertyName)
        {
            return _entityEntry.Member(propertyName);
        }

        public IDbMemberEntry<TEntity, TMember> Member<TMember>(string propertyName)
        {
            return new DbMemberEntryAdapter<TEntity, TMember>(_entityEntry.Member<TMember>(propertyName));
        }

        public DbPropertyEntry<TEntity, TProperty> Property<TProperty>(Expression<Func<TEntity, TProperty>> property)
        {
            return _entityEntry.Property(property);
        }

        public DbPropertyEntry<TEntity, TProperty> Property<TProperty>(string propertyName)
        {
            return _entityEntry.Property<TProperty>(propertyName);
        }

        public DbPropertyEntry Property(string propertyName)
        {
            return _entityEntry.Property(propertyName);
        }

        public DbReferenceEntry<TEntity, TProperty> Reference<TProperty>(
            Expression<Func<TEntity, TProperty>> navigationProperty) where TProperty : class
        {
            return _entityEntry.Reference(navigationProperty);
        }

        public DbReferenceEntry Reference(string navigationProperty)
        {
            return _entityEntry.Reference(navigationProperty);
        }

        public DbReferenceEntry<TEntity, TProperty> Reference<TProperty>(string navigationProperty)
            where TProperty : class
        {
            return _entityEntry.Reference<TProperty>(navigationProperty);
        }

        public void Reload()
        {
            _entityEntry.Reload();
        }

        #endregion
    }
}