﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System;
using System.Collections.Generic;
using System.Data.Entity.Infrastructure;
using System.Data.Entity.Validation;
using System.Diagnostics.Contracts;

namespace Ennf.DbEntityAdapter
{
    internal class DbMemberEntryAdapter<TEntity, TProperty> : IDbMemberEntry<TEntity, TProperty> where TEntity : class
    {
        private readonly DbMemberEntry<TEntity, TProperty> _memberEntry;

        public DbMemberEntryAdapter(DbMemberEntry<TEntity, TProperty> memberEntry)
        {
            Contract.Requires<ArgumentNullException>(memberEntry != null);
            Contract.Ensures(_memberEntry == memberEntry);
            _memberEntry = memberEntry;
        }

        #region IDbMemberEntry<TEntity,TProperty> Members

        public TProperty CurrentValue
        {
            get
            {
                Contract.Ensures(_memberEntry != null);
                Contract.Assert(_memberEntry != null);
                return _memberEntry.CurrentValue;
            }
            set
            {
                Contract.Ensures(value.Equals(_memberEntry.CurrentValue));
                Contract.Assert(_memberEntry != null);
                _memberEntry.CurrentValue = value;
            }
        }

        public IDbEntityEntry<TEntity> EntityEntry
        {
            get
            {
                Contract.Ensures(false);
                throw new NotImplementedException();
            }
        }

        public string Name
        {
            get
            {
                Contract.Ensures(Contract.Result<string>() == _memberEntry.Name);
                Contract.Assert(_memberEntry != null);
                return _memberEntry.Name;
            }
        }

        public ICollection<DbValidationError> GetValidationErrors()
        {
            Contract.Assert(_memberEntry != null);
            return _memberEntry.GetValidationErrors();
        }

        #endregion
    }
}