﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Data.Entity;
using System.Diagnostics.Contracts;
using System.Linq;
using System.Linq.Expressions;

namespace Ennf.DbEntityAdapter
{
    internal class DbSetAdapter<T> : IDbSet<T> where T : class
    {
        private readonly HashSet<T> _data = new HashSet<T>();

        #region Code Contract

        [ContractInvariantMethod]
        private void Invariants()
        {
            Contract.Invariant(_data != null);
        }

        #endregion

        #region IDbSet Interface


        public T Add(T entity)
        {
            _data.Add(entity);
            return entity;
        }

        public T Attach(T entity)
        {
            
            Contract.Ensures(Contract.Result<T>() == entity);
            _data.Add(entity);
            return entity;
        }

        public TDerivedEntity Create<TDerivedEntity>() where TDerivedEntity : class, T
        {
            return Activator.CreateInstance<TDerivedEntity>();
        }

        public T Create()
        {
            return Activator.CreateInstance<T>();
        }

        public T Find(params object[] keyValues)
        {
            Contract.Ensures(false);
            throw new NotImplementedException();
        }

        public ObservableCollection<T> Local
        {
            get { return new ObservableCollection<T>(_data); }
        }

        public T Remove(T entity)
        {
            Contract.Ensures(Contract.Result<T>() == entity);
            _data.Remove(entity);
            return entity;
        }

        public IEnumerator<T> GetEnumerator()
        {
            return _data.GetEnumerator();
        }

        IEnumerator IEnumerable.GetEnumerator()
        {
            return _data.GetEnumerator();
        }

        public Type ElementType
        {
            get { return _data.AsQueryable().ElementType; }
        }

        public Expression Expression
        {
            get
            {
                //Contract.Ensures(Contract.Result<Expression>() == _data.AsQueryable().Expression);
                return _data.AsQueryable().Expression;
            }
        }

        public IQueryProvider Provider
        {
            get
            {
                //Contract.Ensures(Contract.Result<IQueryProvider>() == _data.AsQueryable().Provider);
                return _data.AsQueryable().Provider;
            }
        }

        #endregion
    }
}
