﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity.Infrastructure;
using System.Data.Entity.Validation;
using System.Linq.Expressions;

namespace Ennf.DbEntityAdapter
{
    /// <summary>
    /// This interface creates a missing Interface in the System.Data.Entity namespace
    /// </summary>
    public interface IDbEntityEntry<TEntity> where TEntity : class
    {
        #region Properties

        DbPropertyValues CurrentValues { get; }
        TEntity Entity { get; }
        DbPropertyValues OriginalValues { get; }
        EntityState State { get; set; }

        #endregion

        #region Methods

        IDbCollectionEntry<TEntity, TElement> Collection<TElement>(Expression<Func<TEntity,
                                                                       ICollection<TElement>>> navigationProperty)
            where TElement : class;

        IDbCollectionEntry<TEntity, TElement> Collection<TElement>(string navigationProperty)
            where TElement : class;

        DbCollectionEntry Collection(string navigationProperty);

        DbComplexPropertyEntry<TEntity, TComplexProperty> ComplexProperty<TComplexProperty>(
            Expression<Func<TEntity, TComplexProperty>> propertyValue);

        DbComplexPropertyEntry<TEntity, TComplexProperty> ComplexProperty<TComplexProperty>(string propertyName);
        DbComplexPropertyEntry ComplexProperty(string propertyName);

        bool Equals(Object value);
        bool Equals(DbEntityEntry<TEntity> other);

        DbPropertyValues GetDatabaseValues();
        Type GetType();

        DbEntityValidationResult GetValidationResult();

        DbMemberEntry Member(string propertyName);
        IDbMemberEntry<TEntity, TMember> Member<TMember>(string propertyName);

        DbPropertyEntry<TEntity, TProperty> Property<TProperty>(Expression<Func<TEntity, TProperty>> propertyValue);
        DbPropertyEntry<TEntity, TProperty> Property<TProperty>(string propertyName);
        DbPropertyEntry Property(string propertyName);

        DbReferenceEntry<TEntity, TProperty> Reference<TProperty>(
            Expression<Func<TEntity, TProperty>> navigationProperty) where TProperty : class;

        DbReferenceEntry Reference(string navigationProperty);
        DbReferenceEntry<TEntity, TProperty> Reference<TProperty>(string navigationProperty) where TProperty : class;

        void Reload();

        #endregion
    }
}