﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using Ennf.Functions;
using Ennf.LearningRules;

namespace Ennf.DbEntityAdapter
{
    /// <summary>
    /// Interface for object that takes care of loading the concrete types from the underlying store
    /// </summary>
    public interface IXmlTypeLoader
    {
        INetwork TranslateNetworkFromXml(EnnfTypeNetwork network);

        #region Learning Rule

        ILearningRule TranslateLearningRuleFromXml(LearningRuleType learningRule);

        ILearningRule TranslateLearningRuleFromString(string learningRule);

        string TranslateStringFromLearningRule(ILearningRule learningRule);

        LearningRuleType TranslateXmlFromLearningRule(ILearningRule learningRule);

        #endregion 

        #region Convergence Speed Function

        IConvergenceSpeedFunction TranslateConvergenceSpeedFunctionFromXml(
            ConvergenceSpeedFunctionType convergenceSpeedFunction);

        IConvergenceSpeedFunction TranslateConvergenceSpeedFunctionFromString(string convergenceSpeedFunction);

        string TranslateStringFromConvergenceSpeedFunction(IConvergenceSpeedFunction convergenceSpeedFunction);

        ConvergenceSpeedFunctionType TranslateXmlFromConvergenceSpeedFunction(IConvergenceSpeedFunction convergenceSpeedFunction);

        #endregion

        #region Error Function

        IErrorFunction TranslateErrorFunctionFromXml(ErrorFunctionType errorFunction);

        IErrorFunction TranslateErrorFunctionFromString(string errorFunction);

        string TranslateStringFromErrorFunction(IErrorFunction errorFunction);

        ErrorFunctionType TranslateXmlFromErrorFunction(IErrorFunction errorFunction);

        #endregion

        #region Initialization Function

        IInitializationFunction TranslateInitializationFunctionFromXml(InitializationFunctionType initializationFunction);

        IInitializationFunction TranslateInitializationFunctionFromString(string initializationFunction);

        string TranslateStringFromInitializationFunction(IInitializationFunction initializationFunction);

        InitializationFunctionType TranslateXmlFromInitializationFunction(IInitializationFunction initializationFunction);

        #endregion

        #region Activation Function
        
        IActivationFunction TranslateActivationFunctionFromXml(ActivationFunctionType activationFunction);

        IActivationFunction TranslateActivationFunctionFromString(string activationFunction);

        string TranslateStringFromActivationFunction(IActivationFunction activationFunction);

        ActivationFunctionType TranslateXmlFromActivationFunction(IActivationFunction activationFunction);

        #endregion
        IConnection TranslateConnectionFromXml(EnnfTypeNetworkConnectionsConnectionsConnection connection);

        IInputConnection TranslateInputConnectionFromXml(
            EnnfTypeNetworkConnectionsInputConnectionsInputConnection inputConnection);

        IOutputConnection TranslateOutputConnectionFromXml(
            EnnfTypeNetworkConnectionsOutputConnectionsOutputConnection outputConnection);

        INode TranslateNodeFromXml(EnnfTypeNetworkNodesNode node);

        string UnloadObject(object toserialize);
    }
}
