﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System;
using System.Diagnostics.Contracts;
using Ennf.Properties;

namespace Ennf.Functions.ActivationFunctions
{
    public class IdentityFunction : IActivationFunction,IParentNetwork
    {
        #region IParentNetwork interface
        private INetwork _parentNetwork;
        public INetwork ParentNetwork
        {
            get
            {
                Contract.Ensures(Contract.Result<INetwork>() == _parentNetwork);
                return _parentNetwork;
            }
        }
        INetwork IParentNetwork.ParentNetwork
        {
            set
            {
                Contract.Ensures(_parentNetwork == value);
                _parentNetwork = value;
            }
        }
        #endregion

        [Pure]
        public string Name
        {
            get { return Resources.IdentityFunctionName; }
        }

        public double Calculate(params double[] inputValue)
        {
            Contract.Requires<ArgumentNullException>(inputValue != null);
            Contract.Requires<ArgumentException>(inputValue.Length == 1,Resources.WrongParameterNumber);

            return inputValue[0];
        }

        public double CalculateDerivative(params double[] inputValue)
        {
            return 1;
        }
    }
}
