﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System;
using System.Diagnostics.Contracts;
using Ennf.Properties;
using MathNet.Numerics.Random;

namespace Ennf.Functions.InitializationFunctions
{
    /// <summary>
    /// Function to generate random initialized weights
    /// </summary>
    public class RandomUnitFunction : IInitializationFunction,IParentNetwork
    {
        private readonly WH2006 _rand = new WH2006();

        [ContractInvariantMethod]
        private void Invariant()
        {
            Contract.Invariant(_rand != null);
        }

        /// <summary>
        /// Random Weight Initializers
        /// </summary>
        /// <param name="minimum">Minimum Value</param>
        /// <param name="maximum">Maximum Value</param>
        public RandomUnitFunction(double minimum, double maximum)
        {
            Minimum = minimum;
            Maximum = maximum;
        }

        public RandomUnitFunction()
        {
            
        }

        [Pure]
        public string Name
        {
            get { return Resources.RandomInitializationFuncationName; }
        }

        public double Calculate(params double[] inputValue)
        {
            return _rand.NextDouble() * Math.Abs(Maximum - Minimum) + Minimum;
        }

        public double CalculateDerivative(params double[] inputValue)
        {
            Contract.Ensures(false);
            throw new NotImplementedException();
        }

        #region IInitializationFunction interface
        public double Minimum { get; set; }
        public double Maximum { get; set; }
        #endregion

        #region IParentNetwork interface
        public INetwork ParentNetwork { get; private set; }
        INetwork IParentNetwork.ParentNetwork { set { ParentNetwork = value; } }
        #endregion
    }
}
