﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System.Collections.ObjectModel;

namespace Ennf
{
    /// <summary>
    /// Interface for the Network Models
    /// </summary>
    public interface INetworkModel
    {
        #region Basic Network Operations

        /// <summary>
        /// Creates a empty Neural Network 
        /// </summary>
        /// <remarks>This method is a basic factory method until a better factory setup is developed</remarks>
        /// <returns>An instance of a Neural Network</returns>
        INetwork CreateNetwork();

        /// <summary>
        /// Loads a Neural Network from the underlying database
        /// </summary>
        /// <param name="identifier">Identifier of the Network</param>
        /// <returns>The loaded Network, currently only the BasicFeedForwardNetwork</returns>
        INetwork LoadNetwork(int identifier);

        /// <summary>
        /// Loads the list of all Neural Networks from the underlying database
        /// </summary>
        /// <returns>The list of networks</returns>
        Collection<INetwork> LoadNetwork();

        /// <summary>
        /// Saves the Neural Network changes to the underlying database
        /// </summary>
        void Save();

        /// <summary>
        /// Deletes the Neural Network
        /// </summary>
        /// <param name="deletee">The Neural Network to delete</param>
        void DeleteNetwork(INetwork deletee);

        #endregion

        #region Properties
        /// <summary>
        /// Name of the Model of this Neural Network
        /// </summary>
        string Name { get; }
        /// <summary>
        /// The underlying persitence model
        /// </summary>
        IPersistenceModel PersistenceModel { get; set; }
        #endregion
    }
}