﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

namespace Ennf
{
    /// <summary>
    /// All types of persistence models must implement this Interface so users have
    /// a common access point
    /// </summary>
    public interface IPersistenceModel
    {
        /// <summary>
        /// Loads a file as persitence medium
        /// </summary>
        /// <param name="fileName">The file to load from</param>
        void LoadFile(string fileName);

        /// <summary>
        /// Opens a connection to a database as persistence medium
        /// </summary>
        /// <param name="connectionString">The connection string for the database to connect to</param>
        void ConnectDatabase(string connectionString);

        /// <summary>
        /// Saves the data to the underlying persitence medium
        /// </summary>
        /// <returns></returns>
        int SaveChanges();

        /// <summary>
        /// Closes the file or the connection
        /// </summary>
        void Close();
    }
}
