﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */
using System;
using System.Collections.Generic;
using System.Diagnostics.Contracts;
using System.Runtime.Serialization;
using System.Security.Permissions;

namespace Ennf.Infrastructure
{
    [Serializable]
    public class CsvStreamOutput : IOutput
    {
        #region Constants & Members
        private readonly IList<IList<double>> _resultStore = new List<IList<double>>();
        private int _resultIndex = -1;
        private bool _disposed;
        
        //private const string OUTPUTNAME = "Outputs";
        #endregion

        #region Constructor
        public CsvStreamOutput()
        {
            
        }
        #endregion

        #region Serialization
        /// <summary>
        /// Protected Constructor for de-serialization
        /// </summary>
        /// <param name="info"></param>
        /// <param name="context"></param>
        protected CsvStreamOutput(SerializationInfo info, StreamingContext context)
        {
            //_outputs = info.GetValue(OUTPUTNAME, typeof(Matrix<double>)) as Matrix<double>;
        }

        [SecurityPermission(SecurityAction.Demand, SerializationFormatter = true)]
        public virtual void GetObjectData(SerializationInfo info, StreamingContext context)
        {
           //info.AddValue(OUTPUTNAME,Outputs);
        }
        #endregion

        #region IOutput Members
        public void PutValue(double value)
        {
            Contract.Ensures(_resultIndex - _resultStore.Count < 0);

            if (_resultStore.Count == 0 || _resultStore.Count == _resultIndex)
                _resultStore.Add(new List<double>());
            _resultStore[_resultIndex].Add(value);
        }
        #endregion 

        public bool MoveNextResult()
        {
            Contract.Ensures(-2147483647 <= _resultIndex);
            _resultIndex++;
            return true;
        }

        public void WriteFile()
        {
            
        }

        public IList<IList<double>> Outputs
        {
            get { return _resultStore; }
        }

        /*public Matrix<double> Outputs
        {
            get { return _outputs; }
        }*/

        #region Dispose
        /// <summary>
        /// Internal method according to the Dispose Pattern
        /// </summary>
        /// <remarks>Although nothing needs to be disposed, implemented according to the pattern</remarks>
        /// <param name="disposing"></param>
        protected virtual void Dispose(bool disposing)
        {
            if (!_disposed)
            {
                if (disposing)
                {
                }
            }
            _disposed = true;
        }

        /// <summary>
        /// Used in case there are unmanaged resources which need to be disposed of
        /// </summary>
        public void Dispose()
        {
            Dispose(true);
            GC.SuppressFinalize(this);
        }
        #endregion
    }
}
