﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */
using System;
using System.Collections.Generic;
using System.Diagnostics.Contracts;

namespace Ennf.NetworkModels.BasicFeedForward
{
    public partial class BasicFeedForwardOutputConnection : IOutputConnection
    {
        #region Constructors

        public BasicFeedForwardOutputConnection()
        {
        }

        public BasicFeedForwardOutputConnection(BasicFeedForwardNetwork network)
            : base(network)
        {
            Contract.Requires<ArgumentNullException>(network != null);
            Contract.Requires(network.InitializationFunction != null);
            Contract.Ensures(ParentNetwork != null);
            Contract.Ensures(ParentNetwork.InitializationFunction != null);
        }

        #endregion

        #region IOutputConnection Members

        /// <summary>
        /// While the Output Connection is a IConnection, the Property is not supported for the 
        /// OutputConnection
        /// </summary>
        /// <exception cref="InvalidOperationException">Is always thrown as this operation should not be attempted</exception>
        public override INode OutputNode
        {
            get { return null; }
            set { throw new InvalidOperationException("OutputConnection does not support the OutputNode Property"); }
        }

        public IOutput Output
        {
            get { return ParentNetwork.Output; }
        }

        void IOutputConnection.Calculate()
        {
            using (TraceManager.StartTrace("Ennf.NetworkModels.BasicFeedForward.Calculation"))
            {
                Dictionary<string, object> additionalInformation = new Dictionary<string, object>
                                                                       {{"Output Connection Id", ConnectionId}};
                // Get the Value
                OutputValue = InputNodeInternal.Calculate();
                // Trace Information
                additionalInformation.Add("Return from OutputConnection",OutputValue);
                TraceManager.LogWriter.Write("ReturnValue","Ennf.NetworkModels.BasicFeedForward.Calculation",additionalInformation);
                // Put the Value
                Output.PutValue(OutputValue);
            }
        }
        #endregion
    }
}