﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System.Collections.Generic;
using System.Diagnostics.Contracts;
using Microsoft.Practices.EnterpriseLibrary.Logging;
using Microsoft.Practices.EnterpriseLibrary.Logging.Filters;

namespace Ennf.Utilities
{
    /// <summary>
    /// Provides a dummy instance of the LogWriter in case dependency injection failes
    /// </summary>
    [ContractVerification(false)]
    public class NullLogger : LogWriter 
    {
        private readonly IDictionary<string, LogSource> _traceSources = new Dictionary<string, LogSource>(); 
        #region Overrides of LogWriter

        public override T GetFilter<T>()
        {
            return null;
        }

        public override T GetFilter<T>(string name)
        {
            return null;
        }

        public override ILogFilter GetFilter(string name)
        {
            return null;
        }

        public override IEnumerable<LogSource> GetMatchingTraceSources(LogEntry logEntry)
        {
            return null;
        }

        public override bool IsLoggingEnabled()
        {
            return false;
        }

        public override bool IsTracingEnabled()
        {
            return false;
        }

        public override bool ShouldLog(LogEntry log)
        {
            return false;
        }

        public override void Write(LogEntry log)
        {
        }

        public override IDictionary<string, LogSource> TraceSources
        {
            get { return _traceSources; }
        }

        #endregion
    }
}
