﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */
using System;
using System.Collections.Generic;
using System.Diagnostics.Contracts;
using Microsoft.Practices.Unity;

namespace Ennf.Utilities
{
    /// <summary>
    /// Provides a dummy instance of a unity container in case the resolution failed
    /// </summary>
    [ContractVerification(false)]
    public class NullUnityContainer : IUnityContainer
    {
        #region Properties

        readonly List<ContainerRegistration> _registrations = new List<ContainerRegistration>();
        private bool _disposed;

        #endregion

        #region Implementation of IDisposable
        public void Dispose()
        {
            Dispose(true);
            GC.SuppressFinalize(this);
        }

        protected virtual void Dispose(bool disposing)
        {
            if (!_disposed)
            {
                if (disposing)
                {
                    // Dispose managed resources.
                }

                // There are no unmanaged resources to release, but
                // if we add them, they need to be released here.
            }
            _disposed = true;
        }

        #endregion

        #region Implementation of IUnityContainer

        public IUnityContainer RegisterType(Type @from, Type to, string name, LifetimeManager lifetimeManager, params InjectionMember[] injectionMembers)
        {
            return this;
        }

        public IUnityContainer RegisterInstance(Type t, string name, object instance, LifetimeManager lifetime)
        {
            return this;
        }

        public object Resolve(Type t, string name, params ResolverOverride[] resolverOverrides)
        {
            return null;
        }

        public IEnumerable<object> ResolveAll(Type t, params ResolverOverride[] resolverOverrides)
        {
            return null;
        }

        public object BuildUp(Type t, object existing, string name, params ResolverOverride[] resolverOverrides)
        {
            return null;
        }

        public void Teardown(object o)
        {
            
        }

        public IUnityContainer AddExtension(UnityContainerExtension extension)
        {
            return this;
        }

        public object Configure(Type configurationInterface)
        {
            return null;
        }

        public IUnityContainer RemoveAllExtensions()
        {
            return this;
        }

        public IUnityContainer CreateChildContainer()
        {
            return this;
        }

        public IUnityContainer Parent
        {
            get { return this; }
        }

        public IEnumerable<ContainerRegistration> Registrations
        {
            get { return _registrations; }
        }

        #endregion
    }
}
