﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System.Configuration;
using System.Globalization;
using System.IO;
using EnnfDesigner.BasicFeedForward.Properties;
using EnnfDesigner.Common.RegionControls;
using Microsoft.Practices.Prism.Modularity;
using Microsoft.Practices.Unity;
using EnnfDesigner.BasicFeedForward.Views;
using Microsoft.Practices.Unity.Configuration;

namespace EnnfDesigner.BasicFeedForward
{
    /// <summary>
    /// Module class for loading in Prism
    /// </summary>
    public class BasicFeedForwardModule : IModule
    {
        private const string UnitySectionName = "unity";
        private readonly IUnityContainer _container;

        public BasicFeedForwardModule(IUnityContainer container)
        {
            _container = container;
        }

        public void Initialize()
        {

            // Load the container configuration for the module
            // TODO: change how the Module Configuration File is loaded
            if (!File.Exists(Resources.ModuleConfigurationName))
                throw new FileNotFoundException(string.Format(CultureInfo.CurrentCulture,Resources.ModuleConfigurationFileMissing,Resources.ModuleConfigurationName));

            ExeConfigurationFileMap fileMap = new ExeConfigurationFileMap { ExeConfigFilename = Resources.ModuleConfigurationName };
            Configuration configuration =
                ConfigurationManager.OpenMappedExeConfiguration(fileMap, ConfigurationUserLevel.None);
            UnityConfigurationSection unitySection = (UnityConfigurationSection)configuration.GetSection(UnitySectionName);

            _container.LoadConfiguration(unitySection);
            _container.RegisterType<object, NetworkEditorView>(NavigationNames.NetworkConsole);
        }
    }
}
