﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System;
using System.Windows.Controls;
using EnnfDesigner.BasicFeedForward.ViewModels;
using EnnfDesigner.Common.ShellServices;
using Fluent;
using Microsoft.Practices.Prism.Regions;
using Microsoft.Practices.Unity;
using EnnfDesigner.Common.RegionControls;

namespace EnnfDesigner.BasicFeedForward.Views
{
    /// <summary>
    /// Interaction logic for TrainingConsole.xaml
    /// </summary>
    public partial class TrainingConsoleView : UserControl,INetworkConsole,IConfirmNavigationRequest 
    {
        private readonly IUnityContainer _container;
        private RibbonGroupBox _menu;

        public TrainingConsoleView(IUnityContainer container, TrainingConsoleViewModel model)
        {
            InitializeComponent();
            _container = container;
            Model = model;
        }

        public TrainingConsoleViewModel Model
        {
            set { DataContext = value; }
            get { return DataContext as TrainingConsoleViewModel; }
        }

        private void RegisterMenu()
        {
            IShellService menuService = _container.Resolve<IShellService>();
            _menu = menuService.LoadViewMenu("/views/trainingconsolemenu.xaml",Model);
        }

        #region Implementation of INavigationAware

        public void OnNavigatedTo(NavigationContext navigationContext)
        {
            RegisterMenu();
        }

        public bool IsNavigationTarget(NavigationContext navigationContext)
        {
            return true;
        }

        public void OnNavigatedFrom(NavigationContext navigationContext)
        {
            IShellService menuService = _container.Resolve<IShellService>();
            menuService.UnloadViewMenu(_menu);
            _menu = null;
        }

        public void ConfirmNavigationRequest(NavigationContext navigationContext, Action<bool> continuationCallback)
        {
            continuationCallback(!Model.WorkInProgress);
        }

        #endregion
    }
}
