﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System.Configuration;
using Microsoft.Practices.Prism.Modularity;

namespace EnnfDesigner.Common.ModuleCatalog
{
    public class EnnfModuleConfigurationElement : ModuleConfigurationElement 
    {
         /// <summary>
        /// Initializes a new instance of <see cref="EnnfModuleConfigurationElement"/>.
        /// </summary>
        public EnnfModuleConfigurationElement()
        {
        }

        /// <summary>
        /// Initializes a new instance of <see cref="EnnfModuleConfigurationElement"/>.
        /// </summary>
        /// <param name="assemblyFile">The assembly file where the module is located.</param>
        /// <param name="moduleType">The type of the module.</param>
        /// <param name="moduleName">The name of the module.</param>
        /// <param name="networkType">The type of network the module supports</param>
        /// <param name="startupLoaded">This attribute specifies whether the module is loaded at startup.</param>
        public EnnfModuleConfigurationElement(string assemblyFile, string moduleType, string moduleName, string networkType, bool startupLoaded):base(assemblyFile,moduleType,moduleName,startupLoaded)
        {
            base["networkType"] = networkType;
        }

        /// <summary>
        /// Gets or sets the assembly file.
        /// </summary>
        /// <value>The assembly file.</value>
        [ConfigurationProperty("networkType", IsRequired = true)]
        public string NetworkType
        {
            get { return (string)base["networkType"]; }
            set { base["networkType"] = value; }
        }
    }
}
