﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System;
using Microsoft.Practices.Prism.Modularity;

namespace EnnfDesigner.Common.ModuleCatalog
{
    public class EnnfModuleInfo : ModuleInfo
    {
        public EnnfModuleInfo()
            : base(null, null, new string[0])
        {
            
        }

        /// <summary>
        /// Initializes a new instance of <see cref="EnnfModuleInfo"/>.
        /// </summary>
        /// <param name="name">The module's name.</param>
        /// <param name="type">The module <see cref="Type"/>'s AssemblyQualifiedName.</param>
        /// <param name="networkType">The type of network the module is for</param>
        /// <param name="dependsOn">The modules this instance depends on.</param>
        /// <exception cref="ArgumentNullException">An <see cref="ArgumentNullException"/> is thrown if <paramref name="dependsOn"/> is <see langword="null"/>.</exception>
        public EnnfModuleInfo(string name, string type, string networkType, params string[] dependsOn) : base(name,type,dependsOn)
        {
            NetworkType = networkType.Trim();
        }

        /// <summary>
        /// This tells what kind of NetworkType the Module Supports
        /// </summary>
        public string NetworkType { get; set; }
    }
}
