﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System.Linq;
using Microsoft.Practices.Prism.Logging;
using Microsoft.Practices.Prism.Modularity;

namespace EnnfDesigner.Common.ModuleCatalog
{
    public class EnnfModuleManager : ModuleManager 
    {
        public EnnfModuleManager(IModuleInitializer moduleInitializer, IModuleCatalog moduleCatalog, ILoggerFacade loggerFacade) : base(moduleInitializer, moduleCatalog, loggerFacade)
        {
        }

        /// <summary>
        /// This method resolves which Module belongs to the corresponding ModuleType
        /// </summary>
        /// <param name="networkType">Type of Network</param>
        public void EnsureModule(string networkType)
        {
            var moduleName = from EnnfModuleInfo module in ModuleCatalog.Modules
                             where module.NetworkType == networkType
                             select module.ModuleName;

            LoadModule(moduleName.Single());
        }
    }
}
