﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */
using System;
using System.Reflection;
using System.Windows;
using System.Windows.Baml2006;
using System.Windows.Markup;
using System.Windows.Resources;
using EnnfDesigner.Common.Properties;
using Fluent;

namespace EnnfDesigner.Common.ShellServices
{
    public static class LoadControl
    {
        public static void LoadViewMenu(this IShellService control, string menuName)
        {
            LoadViewMenu(control,menuName,null);    
        }

        public static RibbonGroupBox LoadViewMenu(this IShellService control, string menuName, object dataContext)
        {
            Assembly callingAssembly = Assembly.GetCallingAssembly();
            RibbonGroupBox registerNavigation = FindRibbonGroupBox(callingAssembly, menuName);
            registerNavigation.DataContext = dataContext;
            control.RegisterNavigation(registerNavigation);
            return registerNavigation;
        }

        public static void UnloadViewMenu(this IShellService control, RibbonGroupBox menuToUnload)
        {
            control.DeregisterNavigation(menuToUnload);
        }

        private static RibbonGroupBox FindRibbonGroupBox(Assembly callingAssembly, string menuName)
        {
            Uri uri = new Uri(String.Format("pack://application:,,,/{0};component{1}", callingAssembly.GetName().Name, menuName), UriKind.RelativeOrAbsolute);
            StreamResourceInfo streamResource = Application.GetResourceStream(uri);
            if (streamResource == null)
                throw new ArgumentException(Resources.MenuResourceNotFound, "menuName");
            Baml2006Reader bamlReader = new Baml2006Reader(streamResource.Stream);

            return XamlReader.Load(bamlReader) as RibbonGroupBox;
        }
    }
}
