﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Reflection;
using Ennf.Functions;
using Ennf.LearningRules;

namespace EnnfDesigner.Common.Utilities
{
    /// <summary>
    /// Utility class to find all loaded implementations of the respective functions,
    /// e.g. Error Functions, Activation Functions
    /// </summary>
    public class FunctionFinder
    {
        public static IList<Type> FindLoadedErrorFunctions()
        {
            return FindLoadedFunctionsInternal(typeof (IErrorFunction));
        }

        public static IList<Type> FindLoadedLearningRules()
        {
            return FindLoadedFunctionsInternal(typeof (ILearningRule));
        }

        public static IList<Type> FindLoadedConvergenceSpeedFunctions()
        {
            return FindLoadedFunctionsInternal(typeof (IConvergenceSpeedFunction));
        }

        private static IList<Type> FindLoadedFunctionsInternal(Type typeToFind)
        {
            List<Type> toreturn = new List<Type>();

            // we don't need to check the system assemblies for this
            var assemblies = from a in AppDomain.CurrentDomain.GetAssemblies()
                             where !a.FullName.StartsWith("System")
                             select a;

            foreach (Assembly assembly in assemblies)
            {
                Type[] types = assembly.GetTypes();
                var selectTypes = from t in types
                                  from it in t.GetInterfaces()
                                  where t.IsClass && it.FullName == typeToFind.FullName
                                  select t;

                toreturn.AddRange(selectTypes);
            }
            return toreturn;
        }
    }
}
