﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System;
using System.Globalization;
using System.Windows;
using EnnfDesigner.Properties;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;
using System.Windows.Threading;
using Microsoft.Practices.EnterpriseLibrary.ExceptionHandling;

namespace EnnfDesigner
{
    /// <summary>
    /// Interaction logic for App.xaml
    /// </summary>
    public partial class App : Application
    {
        private ExceptionManager _exceptionHandler;

        public App()
        {
            InitializeComponent();

            Startup += OnStartup;
            Exit += OnExit;
            DispatcherUnhandledException += OnDispatcherUnhandledException;
        }

        private void OnDispatcherUnhandledException(object sender, DispatcherUnhandledExceptionEventArgs dispatcherUnhandledExceptionEventArgs)
        {
            string policyName = Settings.Default.ExceptionPolicyName;

            if (policyName.Length == 0)
                policyName = EnnfDesigner.Properties.Resources.ExceptionPolicyName;

            dispatcherUnhandledExceptionEventArgs.Handled = !_exceptionHandler.HandleException(dispatcherUnhandledExceptionEventArgs.Exception, policyName);

            MessageBox.Show(string.Format(CultureInfo.CurrentUICulture,
                                          EnnfDesigner.Properties.Resources.GenericErrorMessage,
                                          dispatcherUnhandledExceptionEventArgs.Exception.Message),
                            EnnfDesigner.Properties.Resources.GenericErrorMessageTitle, MessageBoxButton.OK,
                            MessageBoxImage.Error);

        }

        private void OnExit(object sender, ExitEventArgs exitEventArgs)
        {
            
        }

        private void OnStartup(object sender, StartupEventArgs startupEventArgs)
        {
            // boot strap everything; if an error occurs here, we have to handle it without
            // Entlib infrastructure, so for now we show a message box;
            try
            {
                Bootstrapper bootstrapper = new Bootstrapper();
                _exceptionHandler = EnterpriseLibraryContainer.Current.GetInstance<ExceptionManager>();
                bootstrapper.Run();
            }
            catch (Exception e)
            {
                MessageBox.Show(
                    string.Format(CultureInfo.CurrentUICulture,EnnfDesigner.Properties.Resources.StartupErrorMessage, e.Message, e.StackTrace),
                    EnnfDesigner.Properties.Resources.StartupErrorMessageTitle, MessageBoxButton.OK, MessageBoxImage.Error);
                Current.Shutdown();
            }
            
            
        }

    }
}
