﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System;
using System.Windows;
using EnnfDesigner.Behaviours;
using EnnfDesigner.Common.ModuleCatalog;
using EnnfDesigner.Common.RegionControls;
using EnnfDesigner.Common.ShellServices;
using EnnfDesigner.Properties;
using Microsoft.Practices.Prism.Modularity;
using Microsoft.Practices.Prism.Regions;
using Microsoft.Practices.Prism.UnityExtensions;
using EnnfDesigner.Views;
using Microsoft.Practices.Unity.Configuration;
using Microsoft.Practices.Unity;

namespace EnnfDesigner
{
    public class Bootstrapper : UnityBootstrapper
    {

        protected override DependencyObject CreateShell()
        {
            // now return the instance of the Shell View
            ShellView toreturn = Container.Resolve<ShellView>();
            Container.RegisterInstance(typeof (IShellService), toreturn, new ContainerControlledLifetimeManager());
            return toreturn;
        }

        protected override void InitializeShell()
        {
            // Show The window
            if (Application.Current != null)
            {
                Application.Current.MainWindow = Shell as Window;
                if (Application.Current.MainWindow == null)
                    throw new NullReferenceException(Resources.MainWindowNullError);
                Application.Current.MainWindow.Show();
            }
        }

        protected override IModuleCatalog CreateModuleCatalog()
        {
            EnnfConfigurationModuleCatalog catalog = new EnnfConfigurationModuleCatalog();
            catalog.Initialize();
            return catalog;
        }

        protected override void ConfigureContainer()
        {
            // load the navigation configuration into the container
            Container.LoadConfiguration(NavigationNames.ConfigurationContainerName);
            Container.RegisterType(typeof (IModuleManager), typeof (EnnfModuleManager),
                                   new ContainerControlledLifetimeManager());
            // see if there are more containers that need loading (e.g. the unity configuration
            // for ennf etc.)
            foreach (string containerName in Settings.Default.UnityContainerNames)
            {
                Container.LoadConfiguration(containerName);
            }
            base.ConfigureContainer();
        }

        protected override IRegionBehaviorFactory ConfigureDefaultRegionBehaviors()
        {
            IRegionBehaviorFactory toreturn = base.ConfigureDefaultRegionBehaviors();

            toreturn.AddIfMissing(Resources.AutoPopulateBehaviourName, typeof(AutoPopulateExportedViewsBehavior));

            return toreturn;
        }
        
    }
}
