﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System.Collections.Generic;
using Ennf;
using Ennf.Utilities;
using Microsoft.Practices.EnterpriseLibrary.Logging;
using Microsoft.Practices.Prism.ViewModel;
using Microsoft.Practices.Unity;

namespace EnnfDesigner.Models
{
    public class NetworkModel : NotificationObject
    {
        private Container _container;
        private ICollection<INetwork> _networks;
        private bool _networkLoaded;

        [Dependency]
        public LogWriter Logger { get; set; }

        [Dependency]
        public IUnityContainer UnityContainer { get; set; }

        public NetworkModel()
        {
            Logger = new NullLogger();
            UnityContainer = new NullUnityContainer();
        }

        /// <summary>
        /// Loads the Networks from a file
        /// </summary>
        /// <param name="filename">The file to load the networks from</param>
        /// <remarks>This will have to change once more than one model comes</remarks>
        public void LoadNetwork(string filename)
        {
            if (_container == null)
                _container = new Container(UnityContainer);

            _container.LoadFile(filename);
            
            RaisePropertyChanged(() => ModelType);
            _networks = _container.NetworkModel.LoadNetwork();
            RaisePropertyChanged(() => Networks);
            Loaded = true;
            RaisePropertyChanged(() => Loaded);
            
        }

        public void CloseNetwork()
        {
            _container.Close();
            RaisePropertyChanged(() => ModelType);
            _networks = null;
            RaisePropertyChanged(() => Networks);
            Loaded = false;
            RaisePropertyChanged(() => Loaded);
        }

        public ICollection<INetwork> Networks { get { return _networks; } }
        public string ModelType { get { return _container.NetworkModel.Name; } }
        public bool Loaded 
        { 
            get { return _networkLoaded; }
            private set 
            { 
                _networkLoaded = value;
                RaisePropertyChanged(() => Loaded);
            } 
        }
    }
}
