﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */
using Fluent;
using EnnfDesigner.ViewModels;
using EnnfDesigner.Common.ShellServices;

namespace EnnfDesigner.Views
{
    /// <summary>
    /// Interaction logic for ShellView.xaml
    /// </summary>
    public partial class ShellView : IShellService
    {

        public ShellView(ShellViewModel viewModel)
        {
            InitializeComponent();
            Model = viewModel;
        }

        private ShellViewModel Model
        {
            get { return DataContext as ShellViewModel; }
            set { DataContext = value; }
        }

        #region IShellService Implementation
        /// <summary>
        /// Implements the Shell Service for views to register their menu
        /// </summary>
        /// <param name="navItem">The menu to add</param>
        /// <remarks>Thinking about moving this away from the view</remarks>
        public void RegisterNavigation(RibbonGroupBox navItem)
        {
            int order = NavigationOrder.GetOrder(navItem);
                
            if (order >= HomeTab.Groups.Count)
                HomeTab.Groups.Add(navItem);
            else
                HomeTab.Groups.Insert(order,navItem);
        }

        public void DeregisterNavigation(RibbonGroupBox navItem)
        {
            HomeTab.Groups.Remove(navItem);
        }

        public void UpdateStatus(ShellStatus status)
        {
            switch (status)
            {
                case ShellStatus.Ready:
                    StatusText.Text = Properties.Resources.ReadyStatus;
                    break;
                case ShellStatus.Processing:
                    StatusText.Text = Properties.Resources.ProcessingStatus;
                    break;
            }
        }

        #endregion
    }
}
