﻿/*
Deployment script for Ennf
*/

GO
SET ANSI_NULLS, ANSI_PADDING, ANSI_WARNINGS, ARITHABORT, CONCAT_NULL_YIELDS_NULL, QUOTED_IDENTIFIER ON;

SET NUMERIC_ROUNDABORT OFF;


GO
:setvar DatabaseName "Ennf"
:setvar DefaultDataPath "C:\Program Files\Microsoft SQL Server\MSSQL10_50.MSSQLSERVER\MSSQL\DATA\"
:setvar DefaultLogPath "C:\Program Files\Microsoft SQL Server\MSSQL10_50.MSSQLSERVER\MSSQL\DATA\"

GO
:on error exit
GO
USE [master]
GO
IF EXISTS (SELECT 1
           FROM   [master].[dbo].[sysdatabases]
           WHERE  [name] = N'$(DatabaseName)')
    BEGIN
        ALTER DATABASE [$(DatabaseName)]
            SET ANSI_NULLS ON,
                ANSI_PADDING ON,
                ANSI_WARNINGS ON,
                ARITHABORT ON,
                CONCAT_NULL_YIELDS_NULL ON,
                QUOTED_IDENTIFIER ON,
                ANSI_NULL_DEFAULT ON,
                CURSOR_DEFAULT LOCAL 
            WITH ROLLBACK IMMEDIATE;
    END


GO
IF EXISTS (SELECT 1
           FROM   [master].[dbo].[sysdatabases]
           WHERE  [name] = N'$(DatabaseName)')
    BEGIN
        ALTER DATABASE [$(DatabaseName)]
            SET PAGE_VERIFY NONE 
            WITH ROLLBACK IMMEDIATE;
    END


GO
ALTER DATABASE [$(DatabaseName)] COLLATE SQL_Latin1_General_CP1_CI_AS;


GO
USE [$(DatabaseName)]
GO
PRINT N'Dropping [AutoCreatedLocal]...';


GO
DROP ROUTE [AutoCreatedLocal];


GO
PRINT N'Creating [ennf]...';


GO
CREATE SCHEMA [ennf]
    AUTHORIZATION [dbo];


GO
PRINT N'Creating [ennf].[Connection_InputConnection]...';


GO
CREATE TABLE [ennf].[Connection_InputConnection] (
    [ConnectionId] INT NOT NULL
);


GO
PRINT N'Creating Connection_InputConnection_PrimaryKey...';


GO
ALTER TABLE [ennf].[Connection_InputConnection]
    ADD CONSTRAINT [Connection_InputConnection_PrimaryKey] PRIMARY KEY CLUSTERED ([ConnectionId] ASC) WITH (ALLOW_PAGE_LOCKS = ON, ALLOW_ROW_LOCKS = ON, PAD_INDEX = OFF, IGNORE_DUP_KEY = OFF, STATISTICS_NORECOMPUTE = OFF);


GO
PRINT N'Creating [ennf].[Network]...';


GO
CREATE TABLE [ennf].[Network] (
    [Identifier]     INT             IDENTITY (1, 1) NOT NULL,
    [NetworkModel]   NVARCHAR (255)  NULL,
    [InputTypename]  NVARCHAR (4000) NULL,
    [InputObject]    VARBINARY (MAX) NULL,
    [OutputTypename] NVARCHAR (4000) NULL,
    [OutputObject]   VARBINARY (MAX) NULL
);


GO
PRINT N'Creating PrimaryKeyNetwork...';


GO
ALTER TABLE [ennf].[Network]
    ADD CONSTRAINT [PrimaryKeyNetwork] PRIMARY KEY CLUSTERED ([Identifier] ASC) WITH (ALLOW_PAGE_LOCKS = ON, ALLOW_ROW_LOCKS = ON, PAD_INDEX = OFF, IGNORE_DUP_KEY = OFF, STATISTICS_NORECOMPUTE = OFF);


GO
PRINT N'Creating [ennf].[Connection]...';


GO
CREATE TABLE [ennf].[Connection] (
    [ConnectionId]     INT   IDENTITY (1, 1) NOT NULL,
    [Output_NodeId_FK] INT   NULL,
    [Input_NodeId_FK]  INT   NULL,
    [Weight]           FLOAT NOT NULL
);


GO
PRINT N'Creating PrimaryKeyConnection...';


GO
ALTER TABLE [ennf].[Connection]
    ADD CONSTRAINT [PrimaryKeyConnection] PRIMARY KEY CLUSTERED ([ConnectionId] ASC) WITH (ALLOW_PAGE_LOCKS = ON, ALLOW_ROW_LOCKS = ON, PAD_INDEX = OFF, IGNORE_DUP_KEY = OFF, STATISTICS_NORECOMPUTE = OFF);


GO
PRINT N'Creating [ennf].[Connection_OutputConnection]...';


GO
CREATE TABLE [ennf].[Connection_OutputConnection] (
    [ConnectionId] INT NOT NULL
);


GO
PRINT N'Creating [ennf].[Node]...';


GO
CREATE TABLE [ennf].[Node] (
    [NodeId]                INT IDENTITY (1, 1) NOT NULL,
    [Network_Identifier_FK] INT NOT NULL,
    [Address_X]             INT NOT NULL,
    [Address_Y]             INT NOT NULL,
    [Address_Z]             INT NOT NULL
);


GO
PRINT N'Creating PrimaryKeyNode...';


GO
ALTER TABLE [ennf].[Node]
    ADD CONSTRAINT [PrimaryKeyNode] PRIMARY KEY CLUSTERED ([NodeId] ASC) WITH (ALLOW_PAGE_LOCKS = ON, ALLOW_ROW_LOCKS = ON, PAD_INDEX = OFF, IGNORE_DUP_KEY = OFF, STATISTICS_NORECOMPUTE = OFF);


GO
PRINT N'Creating NodeUniqueKeyConstraint...';


GO
ALTER TABLE [ennf].[Node]
    ADD CONSTRAINT [NodeUniqueKeyConstraint] UNIQUE NONCLUSTERED ([Network_Identifier_FK] ASC, [Address_X] ASC, [Address_Y] ASC, [Address_Z] ASC) WITH (ALLOW_PAGE_LOCKS = ON, ALLOW_ROW_LOCKS = ON, PAD_INDEX = OFF, IGNORE_DUP_KEY = OFF, STATISTICS_NORECOMPUTE = OFF);


GO
PRINT N'Creating On column: Output_NodeId_FK...';


GO
ALTER TABLE [ennf].[Connection]
    ADD DEFAULT null FOR [Output_NodeId_FK];


GO
PRINT N'Creating On column: Input_NodeId_FK...';


GO
ALTER TABLE [ennf].[Connection]
    ADD DEFAULT null FOR [Input_NodeId_FK];


GO
PRINT N'Creating On column: Weight...';


GO
ALTER TABLE [ennf].[Connection]
    ADD DEFAULT 0 FOR [Weight];


GO
PRINT N'Creating FK_InputConnection_inherits_Connection...';


GO
ALTER TABLE [ennf].[Connection_InputConnection] WITH NOCHECK
    ADD CONSTRAINT [FK_InputConnection_inherits_Connection] FOREIGN KEY ([ConnectionId]) REFERENCES [ennf].[Connection] ([ConnectionId]) ON DELETE CASCADE ON UPDATE NO ACTION;


GO
PRINT N'Creating InputNodeForeignKey...';


GO
ALTER TABLE [ennf].[Connection] WITH NOCHECK
    ADD CONSTRAINT [InputNodeForeignKey] FOREIGN KEY ([Input_NodeId_FK]) REFERENCES [ennf].[Node] ([NodeId]) ON DELETE NO ACTION ON UPDATE NO ACTION;


GO
PRINT N'Creating OutputNodeForeignKey...';


GO
ALTER TABLE [ennf].[Connection] WITH NOCHECK
    ADD CONSTRAINT [OutputNodeForeignKey] FOREIGN KEY ([Output_NodeId_FK]) REFERENCES [ennf].[Node] ([NodeId]) ON DELETE NO ACTION ON UPDATE NO ACTION;


GO
PRINT N'Creating FK_OutputConnection_inherits_Connection...';


GO
ALTER TABLE [ennf].[Connection_OutputConnection] WITH NOCHECK
    ADD CONSTRAINT [FK_OutputConnection_inherits_Connection] FOREIGN KEY ([ConnectionId]) REFERENCES [ennf].[Connection] ([ConnectionId]) ON DELETE CASCADE ON UPDATE NO ACTION;


GO
PRINT N'Creating NodeNetworkForeignKey...';


GO
ALTER TABLE [ennf].[Node] WITH NOCHECK
    ADD CONSTRAINT [NodeNetworkForeignKey] FOREIGN KEY ([Network_Identifier_FK]) REFERENCES [ennf].[Network] ([Identifier]) ON DELETE NO ACTION ON UPDATE NO ACTION;


GO
PRINT N'Checking existing data against newly created constraints';


GO
USE [$(DatabaseName)];


GO
ALTER TABLE [ennf].[Connection_InputConnection] WITH CHECK CHECK CONSTRAINT [FK_InputConnection_inherits_Connection];

ALTER TABLE [ennf].[Connection] WITH CHECK CHECK CONSTRAINT [InputNodeForeignKey];

ALTER TABLE [ennf].[Connection] WITH CHECK CHECK CONSTRAINT [OutputNodeForeignKey];

ALTER TABLE [ennf].[Connection_OutputConnection] WITH CHECK CHECK CONSTRAINT [FK_OutputConnection_inherits_Connection];

ALTER TABLE [ennf].[Node] WITH CHECK CHECK CONSTRAINT [NodeNetworkForeignKey];


GO
