﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Data.Entity;
using System.Linq;
using System.Linq.Expressions;

namespace EnnfTest.NetworkModelsFixture
{
    public class DbSetFixture<T> : IValidationDbSetFixture, IDbSet<T> where T : class
    {
        private readonly HashSet<T> _data;

        #region IDbSet Interface

        public DbSetFixture()
        {
            _data = new HashSet<T>();
        }

        public T Add(T entity)
        {
            _data.Add(entity);
            AddCount++;
            return entity;
        }

        public T Attach(T entity)
        {
            _data.Add(entity);
            AddCount++;
            return entity;
        }

        public TDerivedEntity Create<TDerivedEntity>() where TDerivedEntity : class, T
        {
            CreateCount++;
            return Activator.CreateInstance<TDerivedEntity>();
        }

        public T Create()
        {
            CreateCount++;
            return Activator.CreateInstance<T>();
        }

        public T Find(params object[] keyValues)
        {
            throw new NotImplementedException();
        }

        public ObservableCollection<T> Local
        {
            get { return new ObservableCollection<T>(_data); }
        }

        public T Remove(T entity)
        {
            _data.Remove(entity);
            RemoveCount++;
            return entity;
        }

        public IEnumerator<T> GetEnumerator()
        {
            return _data.GetEnumerator();
        }

        IEnumerator IEnumerable.GetEnumerator()
        {
            return _data.GetEnumerator();
        }

        public Type ElementType
        {
            get { return _data.AsQueryable().ElementType; }
        }

        public Expression Expression
        {
            get { return _data.AsQueryable().Expression; }
        }

        public IQueryProvider Provider
        {
            get { return _data.AsQueryable().Provider; }
        }

        #endregion

        #region TestFixture

        public Type DbSetType
        {
            get { return GetType(); }
        }

        public int AddCount { get; set; }
        public int CreateCount { get; set; }
        public int RemoveCount { get; set; }

        public void ResetCount()
        {
            AddCount = 0;
            CreateCount = 0;
            RemoveCount = 0;
        }

        #endregion
    }
}