﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System;
using System.Collections;
using System.Runtime.Serialization;
using System.Security.Permissions;
using Ennf;

namespace EnnfTest.NetworkModelsFixture
{
    [Serializable]
    public class TestInputTwo : IInput
    {
        private bool disposed;

        public TestInputTwo()
        {
        }

        protected TestInputTwo(SerializationInfo info, StreamingContext context)
        {
        }

        #region IInput Members

        [SecurityPermission(SecurityAction.Demand, SerializationFormatter = true)]
        public virtual void GetObjectData(SerializationInfo info, StreamingContext context)
        {
        }

        public double Current
        {
            get
            {
                var rand = new Random();
                return rand.NextDouble()*1000;
            }
        }

        object IEnumerator.Current
        {
            get { return Current; }
        }

        public bool MoveNext()
        {
            return true;
        }

        public void Reset()
        {
        }

        #endregion

        #region Implementation of the Disposable Patterh

        public void Dispose()
        {
            Dispose(true);
            GC.SuppressFinalize(this);
        }

        protected virtual void Dispose(bool disposing)
        {
            if (!disposed)
            {
                if (disposing)
                {
                    // Free other state (managed objects).
                }
                // Free your own state (unmanaged objects).
                // Set large fields to null.
                disposed = true;
            }
        }

        // Use C# destructor syntax for finalization code.
        ~TestInputTwo()
        {
            // Simply call Dispose(false).
            Dispose(false);
        }

        #endregion

        public bool MoveNextInput()
        {
            throw new NotImplementedException();
        }

        public void ResetInput()
        {
            throw new NotImplementedException();
        }
    }
}