﻿/*
 * ennf - Eddie's Neural Network Framework
 * Copyright 2011 Eduard Ralph
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

using System;
using System.Collections.ObjectModel;
using System.Linq;
using Ennf;
using Ennf.Infrastructure;
using EnnfTest.NetworkModelsFixture;
using EnnfTest.Properties;
using Microsoft.Practices.Unity;
using Microsoft.Practices.Unity.Configuration;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace EnnfTest.UnitTests
{
    [TestClass]
    public class BasicNetworkOperations
    {
        private static Container _ennfContainer;
        private static IUnityContainer _container;
        private static BasicFeedForwardPersistenceModelFixture _persistenceModel;
        
        [ClassInitialize]
        public static void MyClassInitialize(TestContext testContext)
        {
            _container = new UnityContainer();
            _container.LoadConfiguration(Settings.Default.UnityContainerName);

            _ennfContainer = new Container(_container);
            // It really doesn't matter what we try to load here, we just need to initialize
            // the network model and the rest will be taken care by the injected Model fixtre
            _ennfContainer.LoadFile(Resources.TestXmlFile);
            _persistenceModel = _ennfContainer.NetworkModel.PersistenceModel as BasicFeedForwardPersistenceModelFixture;
            Assert.IsNotNull(_persistenceModel);
        }

        [TestInitialize]
        public void SetupData()
        {
            _persistenceModel.ResetData();
        }

        [TestCategory("UnitTests"), TestCategory("Test Network Operations"), TestMethod]
        public void CreateNetwork()
        {
            INetwork network = _ennfContainer.NetworkModel.CreateNetwork();
            _ennfContainer.NetworkModel.Save();

            Assert.AreEqual(1, _persistenceModel.NetworkDbSet.CreateCount);
        }

        [TestCategory("UnitTests"), TestCategory("Test Network Operations"), TestMethod]
        public void LoadNetwork()
        {
            // Load an existing Network
            INetwork network = _ennfContainer.NetworkModel.LoadNetwork(1);
            Assert.IsNotNull(network);
        }

        [TestCategory("UnitTests"), TestCategory("Test Network Operations"), TestMethod]
        public void LoadAllNetworks()
        {
            Collection<INetwork> network = _ennfContainer.NetworkModel.LoadNetwork();
            Assert.AreEqual(2, network.Count());
        }

        [TestCategory("UnitTests"), TestCategory("Test Network Operations"), TestMethod]
        [ExpectedException(typeof (EnnfApplicationException))]
        public void FailLoadNetwork()
        {
            // now try to load a non-existing
            INetwork network = _ennfContainer.NetworkModel.LoadNetwork(9999);
        }

        [TestCategory("UnitTests"), TestCategory("Test Network Operations"), TestMethod]
        [ExpectedException(typeof (ArgumentException))]
        public void FailDeleteNetwork()
        {
            INetwork tofail = new UnknownNetworkType();
            _ennfContainer.NetworkModel.DeleteNetwork(tofail);
        }

        [TestCategory("UnitTests"), TestCategory("Test Network Operations"), TestMethod]
        public void DeleteNetwork()
        {
            INetwork networks = _ennfContainer.NetworkModel.LoadNetwork(1);
            _ennfContainer.NetworkModel.DeleteNetwork(networks);
            _ennfContainer.NetworkModel.Save();

            Assert.AreEqual(_persistenceModel.NetworkDbSet.RemoveCount, 1);
        }

        [TestCategory("UnitTests"), TestCategory("Test Network Operations"), TestMethod]
        public void GetNetworkModel()
        {
            INetwork network = _ennfContainer.NetworkModel.LoadNetwork(1);
            INetworkModel model = network.Parent;
        }

        [TestCleanup]
        public void FinalizeData()
        {
        }
    }
}